@@ -1,8 +1,24 @@
 #!/usr/bin/perl -w
+
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/timeouttest.pl,v 1.4 2003/05/22 14:23:22 muppetman Exp $
+# Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the full
+# list)
+# 
+# This library is free software; you can redistribute it and/or modify it under
+# the terms of the GNU Library General Public License as published by the Free
+# Software Foundation; either version 2.1 of the License, or (at your option)
+# any later version.
+# 
+# This library is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Library General Public License for
+# more details.
+# 
+# You should have received a copy of the GNU Library General Public License
+# along with this library; if not, write to the Free Software Foundation, Inc.,
+# 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# copyright (c) 2003 by muppet
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/timeouttest.pl,v 1.6 2003/09/22 00:04:23 rwmcfa1 Exp $
 #
 
 use Gtk2;
@@ -39,15 +55,9 @@ $button->signal_connect (toggled => sub {
 # here's a timeout that is always running, but only does something if
 # $button is toggled on.
 #
-# the real way...
-#my $id = Glib::Timeout->add (100, sub {
-# the Gtk2 wrapper
-my $id = Gtk2->timeout_add (100, sub {
-#			warn Dumper(\@_);
-			#if ($button->get_active) {
+my $id = Glib::Timeout->add (100, sub {
 			if ($_[0][1]->get_active) {
 				$str++;
-				#$label->set_text ($str);
 				$_[0][0]->set_text ($str);
 			}
 			1;
@@ -71,14 +81,11 @@ $button2->signal_connect (toggled => sub {
 		if (!$_[0]->get_active) {
 			# user turned us off before the callback ran
 			warn "uninstalling $id2";
-			###Gtk2->timeout_remove ($id2);
 			Glib::Source->remove ($id2);
 			$id2 = undef;
 		} else {
-			###$id2 = Gtk2->timeout_add (1000, sub {
 			$id2 = Glib::Timeout->add (1000, sub {
 				warn "callback, $_[0]";
-				#$_[0]->toggle;
 				$_[0]->set_active (0);
 				0;	# don't run again
 				}, $_[0]);
